#[repr(i32)]pub enum ObsDisplayCaptureMethod {
MethodAuto = 0,
MethodDXGI = 1,
MethodWgc = 2,
}Available on Windows only.
Describes the capture method of the monitor capture source.
Used in MonitorCaptureSourceBuilder
Variants
MethodAuto = 0
Automatically selects the best method based on the monitor.
MethodDXGI = 1
Uses DXGI to capture the monitor.
MethodWgc = 2
Uses Windows Graphics Capture to capture the monitor.