pub enum ObsGameCaptureMode {
Any,
CaptureSpecificWindow,
CaptureForegroundWindow,
}Available on Windows only.
Describes the capture mode of the game capture source.
Variants
Any
Captures any fullscreen application
CaptureSpecificWindow
Captures a specific window, specified under the window property
CaptureForegroundWindow
CApture the foreground window when a hotkey is pressed