#[repr(i32)]pub enum ObsWindowCaptureMethod {
MethodAuto = 0,
MethodBitBlt = 1,
MethodWgc = 2,
}Available on Windows only.
Describes the capture method of the window capture source.
Used in WindowCaptureSourceBuilder
Variants
MethodAuto = 0
Automatically selects the best method based on the window.
MethodBitBlt = 1
Uses BitBlt to capture the window. BitBlt (Windows 7 and up)
MethodWgc = 2
Uses Windows Graphics Capture to capture the window. Windows 10 (1903 and up)