#[repr(i32)]pub enum ObsWindowPriority {
Class = 0,
Title = 1,
Executable = 2,
}Available on Windows only.
Describes the priority of the window capture source.
Used in WindowCaptureSourceBuilder
Variants
Class = 0
The window class names must be the same. This means that windows are of the same type.
Title = 1
Window titles must match otherwise, find window with the same class
Executable = 2
Match title, otherwise find window with the same executable