MonitorCaptureSourceBuilder

Struct MonitorCaptureSourceBuilder 

pub struct MonitorCaptureSourceBuilder { /* private fields */ }
Available on Windows only.
Provides an easy-to-use builder for the monitor capture source.

Implementations

Source

impl MonitorCaptureSourceBuilder

pub fn set_monitor_id_raw<T: Into<ObsString> + Sync + Send>( self, monitor_id_raw: T, ) -> Self

pub fn set_capture_cursor(self, capture_cursor: bool) -> Self

Sets whether the cursor should be captured.

pub fn set_compatibility(self, compatibility: bool) -> Self

Compatibility mode for the monitor capture source.

pub fn set_force_sdr(self, force_sdr: bool) -> Self

If the capture should force SDR

Source

impl MonitorCaptureSourceBuilder

pub fn get_monitors() -> Result<Vec<Sendable<DisplayInfo>>, ObsSimpleError>

Gets all available monitors

pub fn set_monitor(self, monitor: &Sendable<DisplayInfo>) -> Self

Source

impl MonitorCaptureSourceBuilder

pub fn set_capture_method(self, method: ObsDisplayCaptureMethod) -> Self

Sets the capture method for the monitor capture source. If you want to use DXGI, it is required for your application to be DPI aware.