pub struct WindowCaptureSourceBuilder { /* private fields */ }Available on Windows only.
Provides an easy-to-use builder for the window capture source.
Implementations
Sourceimpl WindowCaptureSourceBuilder
impl WindowCaptureSourceBuilder
Sourcepub fn set_priority(self, priority: ObsWindowPriority) -> Self
pub fn set_priority(self, priority: ObsWindowPriority) -> Self
Sourcepub fn set_window_raw<T: Into<ObsString> + Sync + Send>(
self,
window_raw: T,
) -> Self
pub fn set_window_raw<T: Into<ObsString> + Sync + Send>( self, window_raw: T, ) -> Self
Sourcepub fn set_cursor(self, cursor: bool) -> Self
pub fn set_cursor(self, cursor: bool) -> Self
Sets whether the cursor should be captured
Sourcepub fn set_force_sdr(self, force_sdr: bool) -> Self
pub fn set_force_sdr(self, force_sdr: bool) -> Self
Whether to force SDR color space for the window capture source.
Sourcepub fn set_client_area(self, client_area: bool) -> Self
pub fn set_client_area(self, client_area: bool) -> Self
Whether to capture the window’s client area only (without borders, title bar and the main menu bar).
pub fn set_compatibility(self, compatibility: bool) -> Self
Sourceimpl WindowCaptureSourceBuilder
impl WindowCaptureSourceBuilder
Sourcepub fn get_windows(
mode: WindowSearchMode,
) -> Result<Vec<Sendable<WindowInfo>>, ObsSimpleError>
pub fn get_windows( mode: WindowSearchMode, ) -> Result<Vec<Sendable<WindowInfo>>, ObsSimpleError>
Gets a list of windows that can be captured by this source.
Sourcepub fn set_window(self, window: &Sendable<WindowInfo>) -> Self
pub fn set_window(self, window: &Sendable<WindowInfo>) -> Self
Sourceimpl WindowCaptureSourceBuilder
impl WindowCaptureSourceBuilder
Sourcepub fn set_capture_method(self, method: ObsWindowCaptureMethod) -> Self
pub fn set_capture_method(self, method: ObsWindowCaptureMethod) -> Self
Sets the capture method for the window capture source.
Sourceimpl WindowCaptureSourceBuilder
impl WindowCaptureSourceBuilder
pub fn set_capture_audio( self, capture_audio: bool, ) -> Result<Self, ObsSimpleError>